@@ -3,7 +3,7 @@ from datetime import date, datetime, timezone
 from zoneinfo import ZoneInfo
 from typing import Optional, Union, Literal, Dict
 
-from .sun import sunrise_sunset, noon, dawn, dusk, midnight  # Importar funciones de sun.py
+from .sun import sunrise_sunset, noon, dawn, dusk, midnight, sun_position  # Importar funciones de sun.py
 
 @dataclass
 class LocationInfo:
@@ -323,6 +323,39 @@ class Location:
             timezone=self.tzinfo if local else timezone.utc
         )
     
+    def sun_position(
+        self,
+        dt: Optional[datetime] = None,
+        local: bool = True,
+        elevation: Optional[float] = None
+    ) -> dict:
+        """
+        Calcula la posición actual del Sol.
+
+        Args:
+            dt: Momento exacto. Si None, usa ahora.
+            local: True para usar zona horaria local.
+            elevation: Elevación del observador.
+
+        Returns:
+            dict: elevation, azimuth, above_horizon, rising
+        """
+        if local and self.timezone is None:
+            raise ValueError("Se solicitó hora local pero no se definió una zona horaria.")
+
+        tz = self.tzinfo if local else timezone.utc
+        dt = dt or datetime.now(tz)
+        elevation = elevation if elevation is not None else self.elevation
+
+        return sun_position(
+            latitude=self.latitude,
+            longitude=self.longitude,
+            dt=dt,
+            elevation=elevation,
+            timezone=tz,
+            with_refraction=True
+        )
+    
     def sun_events(
         self,
         date: Optional[date] = None,
@@ -356,7 +389,8 @@ class Location:
             raise ValueError("Se solicitó hora local pero no se definió una zona horaria.")
 
         tz = self.tzinfo if local else timezone.utc
-        date = date or datetime.now(tz).date()
+        now = datetime.now(tz)
+        date = date or now.date()
         elevation = elevation if elevation is not None else self.elevation
 
         # Calcular amanecer y atardecer
@@ -444,6 +478,9 @@ class Location:
             with_refraction=True,
         )
 
+        # Posición actual del Sol
+        pos = self.sun_position(dt=now, local=local, elevation=elevation)
+
         return {
             "dawn_civil": dawn_civil,
             "dawn_nautical": dawn_nautical,
@@ -456,4 +493,8 @@ class Location:
             "dusk_astronomical": dusk_astronomical,
             "midnight": midnight_time,
             "daylight_duration": daylight_duration,
+            "sun_elevation": pos["elevation"],
+            "sun_azimuth": pos["azimuth"],
+            "sun_horizon_position": pos["horizon_position"],
+            "sun_rising": pos["rising"],
         }
\ No newline at end of file
