@@ -333,6 +333,86 @@ def midnight(
     noon_time = noon(longitude, date, timezone)
     return noon_time + datetime.timedelta(hours=12)
 
+def sun_position(
+    latitude: float,
+    longitude: float,
+    dt: datetime.datetime,
+    elevation: float = 0.0,
+    timezone: datetime.timezone = datetime.timezone.utc,
+    with_refraction: bool = True
+) -> dict:
+    """
+    Calcula la posición del Sol con alta precisión.
+    """
+    if dt.tzinfo is None:
+        dt = dt.replace(tzinfo=timezone)
+    dt_utc = dt.astimezone(datetime.timezone.utc)
+
+    jd = julianday(dt_utc)
+    jc = julianday_to_juliancentury(jd)
+    declination = sun_declination(jc)
+    eqtime = eq_of_time(jc)
+
+    # Tiempo solar verdadero en minutos desde medianoche
+    true_solar_time = (
+        dt_utc.hour * 60 + dt_utc.minute + dt_utc.second / 60.0
+        + eqtime + 4.0 * longitude
+    )
+
+    # Ángulo horario
+    hour_angle = (true_solar_time / 4.0) - 180.0
+    if hour_angle < -180:
+        hour_angle += 360
+    elif hour_angle > 180:
+        hour_angle -= 360
+
+    # Convertir a radianes
+    ha_rad = radians(hour_angle)
+    lat_rad = radians(latitude)
+    dec_rad = radians(declination)
+
+    # Elevación geométrica
+    sin_elev = sin(lat_rad) * sin(dec_rad) + cos(lat_rad) * cos(dec_rad) * cos(ha_rad)
+    elevation_geom = degrees(asin(max(min(sin_elev, 1.0), -1.0)))
+
+    # Corrección por altura del observador
+    elevation_adj = elevation_geom + adjust_to_horizon(elevation)
+
+    # Refracción atmosférica
+    if with_refraction and -10 <= elevation_adj <= 90:
+        refraction = refraction_at_zenith(90.0 - elevation_adj)
+        elevation_final = elevation_adj + refraction
+    else:
+        elevation_final = elevation_adj
+
+    # Azimut (0° = Norte)
+    sin_elev_final = sin(radians(elevation_final))
+    cos_elev_final = cos(radians(elevation_final))
+    cos_lat = cos(lat_rad)
+    sin_lat = sin(lat_rad)
+    sin_dec = sin(dec_rad)
+
+    if abs(cos_elev_final * cos_lat) < 1e-12:
+        azimuth = 180.0 if ha_rad < 0 else 0.0
+    else:
+        cos_az = (sin_dec - sin_elev_final * sin_lat) / (cos_elev_final * cos_lat)
+        cos_az = max(min(cos_az, 1.0), -1.0)
+        azimuth = degrees(acos(cos_az))
+        if hour_angle > 0:  # PM
+            azimuth = 360.0 - azimuth
+
+    horizon_position: Literal["above_horizon", "below_horizon"] = (
+        "above_horizon" if elevation_final > 0 else "below_horizon"
+    )
+    rising = elevation_final > 0 and hour_angle < 0
+
+    return {
+        "elevation": round(elevation_final, 2),
+        "azimuth": round(azimuth, 2),
+        "horizon_position": horizon_position,
+        "rising": rising
+    }
+
 # 🎁 FUNCIÓN BONUS: Todo junto (opcional)
 def all_sun_events(
     latitude: float, longitude: float, date: datetime.date,
